use Market;

-- 1) List of the products with a price greater than 50 euros.
Select ID as ID_Product, description
from PRODUCTS
where price > 50


-- 1.a) List of the products with a price at least 50 euros.
Select ID as ID_Product, description
from PRODUCTS
where price >= 50

--2) List customers who wrote ONLY reviews with rate greater than 4.
Select c.id, c.surname, c.name 
from customers c join reviews r on c.id=r.customer
where r.rate > 4
except
Select c.id, c.surname, c.name 
from customers c join reviews r on c.id=r.customer
where r.rate <= 4
--alternative with NOT IN

Select distinct c.id, c.surname, c.name 
from customers c join reviews r on c.id=r.customer
where r.rate > 4 and 
				c.id NOT IN (Select c.id 
				from customers c join reviews r on c.id=r.customer
				where r.rate <= 4
				)
				
				
--List customer from Livorno bought products with category Arte
--tables: customers, purchases, products

select  distinct c.id, c.surname, c.name
from customers c JOIN purchases p ON c.id=p.customer JOIN
products pr ON p.product=pr.id
where c.city='livorno' and pr.category='Arte'


--List products that received reviews
select distinct p.ID, p.DESCRIPTION
from reviews r join products p on p.id=r.PRODUCT

--List products that received reviews from customers from Pisa in the 
--year 2013 and from Livorno or Florence in 2010.
--tables: products, reviews, customers

select distinct p.id, p.DESCRIPTION
from products p join reviews r on r.PRODUCT=p.id JOIN
customers c ON c.id=r.customer
where (c.city = 'pisa' and r.date like '%2013%') or 
((c.city='livorno' or c.city='florence') and year(r.date)=2010)

--r.date like '%2013% equivalent year(r.date)=2013


-- alternative
select  p.id, p.DESCRIPTION
from products p join reviews r on r.PRODUCT=p.id JOIN
customers c ON c.id=r.customer
where c.city = 'pisa' and r.date like '%2013%'
UNION
select  p.id, p.DESCRIPTION
from products p join reviews r on r.PRODUCT=p.id JOIN
customers c ON c.id=r.customer
where (city='livorno' or city='florence') and year(r.date)=2010


--List products that received reviews from customers from Pisa in the 
--year 2013 and from Livorno AND Florence in 2010.
-- Note that 2010 is referring to both Livorno and Florence 
--tables: products, reviews, customers

select  p.id, p.DESCRIPTION
from products p join reviews r on r.PRODUCT=p.id JOIN
customers c ON c.id=r.customer
where c.city = 'pisa' and r.date like '%2013%'
UNION
select  p.id, p.DESCRIPTION
from products p join reviews r on r.PRODUCT=p.id JOIN
customers c ON c.id=r.customer
where (city='livorno' AND city='florence') and year(r.date)=2010


--List products that received reviews BOTH: 
--a) from customers from Pisa in the year 2013 and 
--b) from Livorno or Florence in 2010.
--tables: products, reviews, customers

select  p.id, p.DESCRIPTION
from products p join reviews r on r.PRODUCT=p.id JOIN
customers c ON c.id=r.customer
where c.city = 'pisa' and r.date like '%2013%'
--a)
INTERSECT
select  p.id, p.DESCRIPTION
from products p join reviews r on r.PRODUCT=p.id JOIN
customers c ON c.id=r.customer
where (city='livorno' or city='florence') and year(r.date)=2010
-- b)

-- For each customer return the total amount spent in 2013
-- tables: customers, purchases, products

select c.id, c.surname, c.name, sum(p.price) as TotalSpent
from products p join purchases pu on p.id=pu.product 
join customers c on c.id=pu.customer
where year(pu.date)=2013
group by c.ID, c.surname, c.name
order by surname

-- For each customer who bought at least 10 products 
-- return the average amount spent

Select c.id, c.surname, c.name, avg(p.price) as AVGAMOUNT 
from products p JOIN purchases pu on p.id=pu.product JOIN
customers c on c.id = pu.customer
group by c.id, c.surname, c.name
--having count(*) >= 10
having count(pu.product) >= 10

-- For each customer who bought at least 10 distinct products 
-- return the average amount spent

Select c.id, c.surname, c.name, avg(p.price) as AVGAMOUNT 
from products p JOIN purchases pu on p.id=pu.product JOIN
customers c on c.id = pu.customer
group by c.id, c.surname, c.name
having count(distinct pu.product) >= 10

--13.a) How the number of purchased products  is distributed 
--over the years?
-- for each year provide the number of purchased products

select count(*) AS NPurchases, year(p.date) as year
from purchases p
group by year(p.date)
order by year




